"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MSG_UUID(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MSB_FIELD_NUMBER: builtins.int
    LSB_FIELD_NUMBER: builtins.int
    msb: builtins.int = ...
    lsb: builtins.int = ...
    def __init__(
        self,
        *,
        msb: builtins.int = ...,
        lsb: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["lsb", b"lsb", "msb", b"msb"]
    ) -> None: ...

global___MSG_UUID = MSG_UUID

class MSG_UUID_AND_VERSION(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MSB_FIELD_NUMBER: builtins.int
    LSB_FIELD_NUMBER: builtins.int
    VER_FIELD_NUMBER: builtins.int
    msb: builtins.int = ...
    lsb: builtins.int = ...
    ver: builtins.int = ...
    def __init__(
        self,
        *,
        msb: builtins.int = ...,
        lsb: builtins.int = ...,
        ver: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "lsb", b"lsb", "msb", b"msb", "ver", b"ver"
        ],
    ) -> None: ...

global___MSG_UUID_AND_VERSION = MSG_UUID_AND_VERSION

class MSG_UUIDs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UUIDS_FIELD_NUMBER: builtins.int
    @property
    def uuids(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MSG_UUID
    ]: ...
    def __init__(
        self,
        *,
        uuids: typing.Optional[typing.Iterable[global___MSG_UUID]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["uuids", b"uuids"]
    ) -> None: ...

global___MSG_UUIDs = MSG_UUIDs

class MSG_OptionalSerial(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRESENT_FIELD_NUMBER: builtins.int
    SERIAL_FIELD_NUMBER: builtins.int
    present: builtins.bool = ...
    serial: builtins.int = ...
    def __init__(
        self,
        *,
        present: builtins.bool = ...,
        serial: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "present", b"present", "serial", b"serial"
        ],
    ) -> None: ...

global___MSG_OptionalSerial = MSG_OptionalSerial

class MSG_Notification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _Type(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Type.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        Fact = MSG_Notification.Type.V(0)
        Id = MSG_Notification.Type.V(1)
        Catchup = MSG_Notification.Type.V(2)
        Complete = MSG_Notification.Type.V(3)
        Facts = MSG_Notification.Type.V(4)
    class Type(metaclass=_Type):
        V = typing.NewType("V", builtins.int)
    Fact = MSG_Notification.Type.V(0)
    Id = MSG_Notification.Type.V(1)
    Catchup = MSG_Notification.Type.V(2)
    Complete = MSG_Notification.Type.V(3)
    Facts = MSG_Notification.Type.V(4)

    TYPE_FIELD_NUMBER: builtins.int
    FACT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    FACTS_FIELD_NUMBER: builtins.int
    type: global___MSG_Notification.Type.V = ...
    @property
    def fact(self) -> global___MSG_Fact: ...
    @property
    def id(self) -> global___MSG_UUID: ...
    @property
    def facts(self) -> global___MSG_Facts: ...
    def __init__(
        self,
        *,
        type: global___MSG_Notification.Type.V = ...,
        fact: typing.Optional[global___MSG_Fact] = ...,
        id: typing.Optional[global___MSG_UUID] = ...,
        facts: typing.Optional[global___MSG_Facts] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "fact", b"fact", "facts", b"facts", "id", b"id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "fact", b"fact", "facts", b"facts", "id", b"id", "type", b"type"
        ],
    ) -> None: ...

global___MSG_Notification = MSG_Notification

class MSG_SubscriptionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JSON_FIELD_NUMBER: builtins.int
    json: typing.Text = ...
    def __init__(
        self,
        *,
        json: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["json", b"json"]
    ) -> None: ...

global___MSG_SubscriptionRequest = MSG_SubscriptionRequest

class MSG_FactSpecsJson(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JSON_FIELD_NUMBER: builtins.int
    json: typing.Text = ...
    def __init__(
        self,
        *,
        json: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["json", b"json"]
    ) -> None: ...

global___MSG_FactSpecsJson = MSG_FactSpecsJson

class MSG_OptionalFact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRESENT_FIELD_NUMBER: builtins.int
    FACT_FIELD_NUMBER: builtins.int
    present: builtins.bool = ...
    @property
    def fact(self) -> global___MSG_Fact: ...
    def __init__(
        self,
        *,
        present: builtins.bool = ...,
        fact: typing.Optional[global___MSG_Fact] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["fact", b"fact"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["fact", b"fact", "present", b"present"],
    ) -> None: ...

global___MSG_OptionalFact = MSG_OptionalFact

class MSG_OptionalUuid(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRESENT_FIELD_NUMBER: builtins.int
    UUID_FIELD_NUMBER: builtins.int
    present: builtins.bool = ...
    @property
    def uuid(self) -> global___MSG_UUID: ...
    def __init__(
        self,
        *,
        present: builtins.bool = ...,
        uuid: typing.Optional[global___MSG_UUID] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["uuid", b"uuid"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["present", b"present", "uuid", b"uuid"],
    ) -> None: ...

global___MSG_OptionalUuid = MSG_OptionalUuid

class MSG_Fact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    header: typing.Text = ...
    payload: typing.Text = ...
    def __init__(
        self,
        *,
        header: typing.Text = ...,
        payload: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "header", b"header", "payload", b"payload"
        ],
    ) -> None: ...

global___MSG_Fact = MSG_Fact

class MSG_Facts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FACT_FIELD_NUMBER: builtins.int
    @property
    def fact(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MSG_Fact
    ]: ...
    def __init__(
        self,
        *,
        fact: typing.Optional[typing.Iterable[global___MSG_Fact]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["fact", b"fact"]
    ) -> None: ...

global___MSG_Facts = MSG_Facts

class MSG_ConditionalPublishRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FACTS_FIELD_NUMBER: builtins.int
    TOKENPRESENT_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    tokenPresent: builtins.bool = ...
    @property
    def facts(self) -> global___MSG_Facts: ...
    @property
    def token(self) -> global___MSG_UUID: ...
    def __init__(
        self,
        *,
        facts: typing.Optional[global___MSG_Facts] = ...,
        tokenPresent: builtins.bool = ...,
        token: typing.Optional[global___MSG_UUID] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["facts", b"facts", "token", b"token"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "facts", b"facts", "token", b"token", "tokenPresent", b"tokenPresent"
        ],
    ) -> None: ...

global___MSG_ConditionalPublishRequest = MSG_ConditionalPublishRequest

class MSG_ConditionalPublishResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool = ...
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["success", b"success"]
    ) -> None: ...

global___MSG_ConditionalPublishResult = MSG_ConditionalPublishResult

class MSG_Empty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___MSG_Empty = MSG_Empty

class MSG_ServerProtocolVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAJOR_FIELD_NUMBER: builtins.int
    MINOR_FIELD_NUMBER: builtins.int
    PATCH_FIELD_NUMBER: builtins.int
    major: builtins.int = ...
    minor: builtins.int = ...
    patch: builtins.int = ...
    def __init__(
        self,
        *,
        major: builtins.int = ...,
        minor: builtins.int = ...,
        patch: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "major", b"major", "minor", b"minor", "patch", b"patch"
        ],
    ) -> None: ...

global___MSG_ServerProtocolVersion = MSG_ServerProtocolVersion

class MSG_ServerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class PropertyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...
        value: typing.Text = ...
        def __init__(
            self,
            *,
            key: typing.Text = ...,
            value: typing.Text = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal["key", b"key", "value", b"value"],
        ) -> None: ...
    PROPERTY_FIELD_NUMBER: builtins.int
    @property
    def property(
        self,
    ) -> google.protobuf.internal.containers.ScalarMap[typing.Text, typing.Text]: ...
    def __init__(
        self,
        *,
        property: typing.Optional[typing.Mapping[typing.Text, typing.Text]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["property", b"property"]
    ) -> None: ...

global___MSG_ServerProperties = MSG_ServerProperties

class MSG_ServerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VERSION_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def version(self) -> global___MSG_ServerProtocolVersion: ...
    @property
    def properties(self) -> global___MSG_ServerProperties: ...
    def __init__(
        self,
        *,
        version: typing.Optional[global___MSG_ServerProtocolVersion] = ...,
        properties: typing.Optional[global___MSG_ServerProperties] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "properties", b"properties", "version", b"version"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "properties", b"properties", "version", b"version"
        ],
    ) -> None: ...

global___MSG_ServerConfig = MSG_ServerConfig

class MSG_StringSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EMBEDDEDSTRING_FIELD_NUMBER: builtins.int
    embeddedString: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    def __init__(
        self,
        *,
        embeddedString: typing.Optional[typing.Iterable[typing.Text]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["embeddedString", b"embeddedString"]
    ) -> None: ...

global___MSG_StringSet = MSG_StringSet

class MSG_String(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EMBEDDEDSTRING_FIELD_NUMBER: builtins.int
    embeddedString: typing.Text = ...
    def __init__(
        self,
        *,
        embeddedString: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["embeddedString", b"embeddedString"]
    ) -> None: ...

global___MSG_String = MSG_String

class MSG_StateForRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NSPRESENT_FIELD_NUMBER: builtins.int
    NS_FIELD_NUMBER: builtins.int
    AGGIDS_FIELD_NUMBER: builtins.int
    nsPresent: builtins.bool = ...
    ns: typing.Text = ...
    @property
    def aggIds(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MSG_UUID
    ]: ...
    def __init__(
        self,
        *,
        nsPresent: builtins.bool = ...,
        ns: typing.Text = ...,
        aggIds: typing.Optional[typing.Iterable[global___MSG_UUID]] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "aggIds", b"aggIds", "ns", b"ns", "nsPresent", b"nsPresent"
        ],
    ) -> None: ...

global___MSG_StateForRequest = MSG_StateForRequest

class MSG_CurrentDatabaseTime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MILLIS_FIELD_NUMBER: builtins.int
    millis: builtins.int = ...
    def __init__(
        self,
        *,
        millis: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["millis", b"millis"]
    ) -> None: ...

global___MSG_CurrentDatabaseTime = MSG_CurrentDatabaseTime

class MSG_SnapshotId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    UUID_FIELD_NUMBER: builtins.int
    key: typing.Text = ...
    @property
    def uuid(self) -> global___MSG_OptionalUuid: ...
    def __init__(
        self,
        *,
        key: typing.Text = ...,
        uuid: typing.Optional[global___MSG_OptionalUuid] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["uuid", b"uuid"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["key", b"key", "uuid", b"uuid"]
    ) -> None: ...

global___MSG_SnapshotId = MSG_SnapshotId

class MSG_Snapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    FACTID_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    COMPRESSED_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    compressed: builtins.bool = ...
    @property
    def id(self) -> global___MSG_SnapshotId: ...
    @property
    def factId(self) -> global___MSG_UUID: ...
    def __init__(
        self,
        *,
        id: typing.Optional[global___MSG_SnapshotId] = ...,
        factId: typing.Optional[global___MSG_UUID] = ...,
        data: builtins.bytes = ...,
        compressed: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["factId", b"factId", "id", b"id"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "compressed",
            b"compressed",
            "data",
            b"data",
            "factId",
            b"factId",
            "id",
            b"id",
        ],
    ) -> None: ...

global___MSG_Snapshot = MSG_Snapshot

class MSG_OptionalSnapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRESENT_FIELD_NUMBER: builtins.int
    SNAPSHOT_FIELD_NUMBER: builtins.int
    present: builtins.bool = ...
    @property
    def snapshot(self) -> global___MSG_Snapshot: ...
    def __init__(
        self,
        *,
        present: builtins.bool = ...,
        snapshot: typing.Optional[global___MSG_Snapshot] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["snapshot", b"snapshot"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "present", b"present", "snapshot", b"snapshot"
        ],
    ) -> None: ...

global___MSG_OptionalSnapshot = MSG_OptionalSnapshot



import re
from uuid import UUID
from pyfactcast.client.entities import Fact
from typing import Iterable, List
from pyfactcast.client.sync import FactStore


fact_store = FactStore()


def filter_types(*, fs: FactStore, namespace: str, it: Iterable[str]) -> Iterable[str]:
    if not it:
        return it

    types_for_namespace = fs.enumerate_types(namespace=namespace)
    res = set()

    # TODO: Make the regex stuff beautiful
    regexes = [re.compile(elem) for elem in it]
    for regexp in regexes:
        res.update(list(filter(regexp.fullmatch, types_for_namespace)))

    return res


def subscribe(
    namespace: str,
    follow: bool,
    from_now: bool = False,
    after_fact: UUID = None,
    fact_types: List[str] = [],
) -> Iterable[Fact]:

    with fact_store as fs:
        return fs.subscribe(
            namespace=namespace,
            continuous=follow,
            from_now=from_now,
            after_fact=after_fact,
            fact_types=filter_types(fs=fs, namespace=namespace, it=fact_types),
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FactStore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="FactStore.proto",
    package="org.factcast.grpc.api.gen",
    syntax="proto3",
    serialized_options=b"\n\031org.factcast.grpc.api.genB\016FactStoreProtoP\000",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x0f\x46\x61\x63tStore.proto\x12\x19org.factcast.grpc.api.gen"$\n\x08MSG_UUID\x12\x0b\n\x03msb\x18\x01 \x01(\x03\x12\x0b\n\x03lsb\x18\x02 \x01(\x03"=\n\x14MSG_UUID_AND_VERSION\x12\x0b\n\x03msb\x18\x01 \x01(\x03\x12\x0b\n\x03lsb\x18\x02 \x01(\x03\x12\x0b\n\x03ver\x18\x03 \x01(\x05"?\n\tMSG_UUIDs\x12\x32\n\x05uuids\x18\x01 \x03(\x0b\x32#.org.factcast.grpc.api.gen.MSG_UUID"5\n\x12MSG_OptionalSerial\x12\x0f\n\x07present\x18\x01 \x01(\x08\x12\x0e\n\x06serial\x18\x02 \x01(\x04"\xab\x02\n\x10MSG_Notification\x12>\n\x04type\x18\x01 \x01(\x0e\x32\x30.org.factcast.grpc.api.gen.MSG_Notification.Type\x12\x31\n\x04\x66\x61\x63t\x18\x02 \x01(\x0b\x32#.org.factcast.grpc.api.gen.MSG_Fact\x12/\n\x02id\x18\x03 \x01(\x0b\x32#.org.factcast.grpc.api.gen.MSG_UUID\x12\x33\n\x05\x66\x61\x63ts\x18\x04 \x01(\x0b\x32$.org.factcast.grpc.api.gen.MSG_Facts">\n\x04Type\x12\x08\n\x04\x46\x61\x63t\x10\x00\x12\x06\n\x02Id\x10\x01\x12\x0b\n\x07\x43\x61tchup\x10\x02\x12\x0c\n\x08\x43omplete\x10\x03\x12\t\n\x05\x46\x61\x63ts\x10\x04"\'\n\x17MSG_SubscriptionRequest\x12\x0c\n\x04json\x18\x01 \x01(\t"!\n\x11MSG_FactSpecsJson\x12\x0c\n\x04json\x18\x01 \x01(\t"V\n\x10MSG_OptionalFact\x12\x0f\n\x07present\x18\x01 \x01(\x08\x12\x31\n\x04\x66\x61\x63t\x18\x02 \x01(\x0b\x32#.org.factcast.grpc.api.gen.MSG_Fact"V\n\x10MSG_OptionalUuid\x12\x0f\n\x07present\x18\x01 \x01(\x08\x12\x31\n\x04uuid\x18\x02 \x01(\x0b\x32#.org.factcast.grpc.api.gen.MSG_UUID"+\n\x08MSG_Fact\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\t">\n\tMSG_Facts\x12\x31\n\x04\x66\x61\x63t\x18\x01 \x03(\x0b\x32#.org.factcast.grpc.api.gen.MSG_Fact"\x9e\x01\n\x1dMSG_ConditionalPublishRequest\x12\x33\n\x05\x66\x61\x63ts\x18\x01 \x01(\x0b\x32$.org.factcast.grpc.api.gen.MSG_Facts\x12\x14\n\x0ctokenPresent\x18\x02 \x01(\x08\x12\x32\n\x05token\x18\x03 \x01(\x0b\x32#.org.factcast.grpc.api.gen.MSG_UUID"/\n\x1cMSG_ConditionalPublishResult\x12\x0f\n\x07success\x18\x01 \x01(\x08"\x0b\n\tMSG_Empty"H\n\x19MSG_ServerProtocolVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05patch\x18\x03 \x01(\x05"\x98\x01\n\x14MSG_ServerProperties\x12O\n\x08property\x18\x01 \x03(\x0b\x32=.org.factcast.grpc.api.gen.MSG_ServerProperties.PropertyEntry\x1a/\n\rPropertyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x9e\x01\n\x10MSG_ServerConfig\x12\x45\n\x07version\x18\x01 \x01(\x0b\x32\x34.org.factcast.grpc.api.gen.MSG_ServerProtocolVersion\x12\x43\n\nproperties\x18\x02 \x01(\x0b\x32/.org.factcast.grpc.api.gen.MSG_ServerProperties"\'\n\rMSG_StringSet\x12\x16\n\x0e\x65mbeddedString\x18\x01 \x03(\t"$\n\nMSG_String\x12\x16\n\x0e\x65mbeddedString\x18\x01 \x01(\t"i\n\x13MSG_StateForRequest\x12\x11\n\tnsPresent\x18\x01 \x01(\x08\x12\n\n\x02ns\x18\x02 \x01(\t\x12\x33\n\x06\x61ggIds\x18\x03 \x03(\x0b\x32#.org.factcast.grpc.api.gen.MSG_UUID")\n\x17MSG_CurrentDatabaseTime\x12\x0e\n\x06millis\x18\x01 \x01(\x03"X\n\x0eMSG_SnapshotId\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x04uuid\x18\x02 \x01(\x0b\x32+.org.factcast.grpc.api.gen.MSG_OptionalUuid"\x9c\x01\n\x0cMSG_Snapshot\x12\x35\n\x02id\x18\x01 \x01(\x0b\x32).org.factcast.grpc.api.gen.MSG_SnapshotId\x12\x33\n\x06\x66\x61\x63tId\x18\x02 \x01(\x0b\x32#.org.factcast.grpc.api.gen.MSG_UUID\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x12\n\ncompressed\x18\x04 \x01(\x08"b\n\x14MSG_OptionalSnapshot\x12\x0f\n\x07present\x18\x01 \x01(\x08\x12\x39\n\x08snapshot\x18\x02 \x01(\x0b\x32\'.org.factcast.grpc.api.gen.MSG_Snapshot2\x96\r\n\x0fRemoteFactStore\x12p\n\tsubscribe\x12\x32.org.factcast.grpc.api.gen.MSG_SubscriptionRequest\x1a+.org.factcast.grpc.api.gen.MSG_Notification"\x00\x30\x01\x12_\n\tfetchById\x12#.org.factcast.grpc.api.gen.MSG_UUID\x1a+.org.factcast.grpc.api.gen.MSG_OptionalFact"\x00\x12W\n\x07publish\x12$.org.factcast.grpc.api.gen.MSG_Facts\x1a$.org.factcast.grpc.api.gen.MSG_Empty"\x00\x12`\n\x08serialOf\x12#.org.factcast.grpc.api.gen.MSG_UUID\x1a-.org.factcast.grpc.api.gen.MSG_OptionalSerial"\x00\x12`\n\thandshake\x12$.org.factcast.grpc.api.gen.MSG_Empty\x1a+.org.factcast.grpc.api.gen.MSG_ServerConfig"\x00\x12g\n\x13\x65numerateNamespaces\x12$.org.factcast.grpc.api.gen.MSG_Empty\x1a(.org.factcast.grpc.api.gen.MSG_StringSet"\x00\x12\x63\n\x0e\x65numerateTypes\x12%.org.factcast.grpc.api.gen.MSG_String\x1a(.org.factcast.grpc.api.gen.MSG_StringSet"\x00\x12\x89\x01\n\x12publishConditional\x12\x38.org.factcast.grpc.api.gen.MSG_ConditionalPublishRequest\x1a\x37.org.factcast.grpc.api.gen.MSG_ConditionalPublishResult"\x00\x12Y\n\ninvalidate\x12#.org.factcast.grpc.api.gen.MSG_UUID\x1a$.org.factcast.grpc.api.gen.MSG_Empty"\x00\x12\x61\n\x08stateFor\x12..org.factcast.grpc.api.gen.MSG_StateForRequest\x1a#.org.factcast.grpc.api.gen.MSG_UUID"\x00\x12i\n\x0b\x63urrentTime\x12$.org.factcast.grpc.api.gen.MSG_Empty\x1a\x32.org.factcast.grpc.api.gen.MSG_CurrentDatabaseTime"\x00\x12u\n\x13\x66\x65tchByIdAndVersion\x12/.org.factcast.grpc.api.gen.MSG_UUID_AND_VERSION\x1a+.org.factcast.grpc.api.gen.MSG_OptionalFact"\x00\x12\x62\n\rclearSnapshot\x12).org.factcast.grpc.api.gen.MSG_SnapshotId\x1a$.org.factcast.grpc.api.gen.MSG_Empty"\x00\x12^\n\x0bsetSnapshot\x12\'.org.factcast.grpc.api.gen.MSG_Snapshot\x1a$.org.factcast.grpc.api.gen.MSG_Empty"\x00\x12k\n\x0bgetSnapshot\x12).org.factcast.grpc.api.gen.MSG_SnapshotId\x1a/.org.factcast.grpc.api.gen.MSG_OptionalSnapshot"\x00\x12h\n\x11stateForSpecsJson\x12,.org.factcast.grpc.api.gen.MSG_FactSpecsJson\x1a#.org.factcast.grpc.api.gen.MSG_UUID"\x00\x42-\n\x19org.factcast.grpc.api.genB\x0e\x46\x61\x63tStoreProtoP\x00\x62\x06proto3',
)


_MSG_NOTIFICATION_TYPE = _descriptor.EnumDescriptor(
    name="Type",
    full_name="org.factcast.grpc.api.gen.MSG_Notification.Type",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="Fact",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="Id",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="Catchup",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="Complete",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="Facts",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=505,
    serialized_end=567,
)
_sym_db.RegisterEnumDescriptor(_MSG_NOTIFICATION_TYPE)


_MSG_UUID = _descriptor.Descriptor(
    name="MSG_UUID",
    full_name="org.factcast.grpc.api.gen.MSG_UUID",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msb",
            full_name="org.factcast.grpc.api.gen.MSG_UUID.msb",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="lsb",
            full_name="org.factcast.grpc.api.gen.MSG_UUID.lsb",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=46,
    serialized_end=82,
)


_MSG_UUID_AND_VERSION = _descriptor.Descriptor(
    name="MSG_UUID_AND_VERSION",
    full_name="org.factcast.grpc.api.gen.MSG_UUID_AND_VERSION",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msb",
            full_name="org.factcast.grpc.api.gen.MSG_UUID_AND_VERSION.msb",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="lsb",
            full_name="org.factcast.grpc.api.gen.MSG_UUID_AND_VERSION.lsb",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ver",
            full_name="org.factcast.grpc.api.gen.MSG_UUID_AND_VERSION.ver",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=84,
    serialized_end=145,
)


_MSG_UUIDS = _descriptor.Descriptor(
    name="MSG_UUIDs",
    full_name="org.factcast.grpc.api.gen.MSG_UUIDs",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="uuids",
            full_name="org.factcast.grpc.api.gen.MSG_UUIDs.uuids",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=147,
    serialized_end=210,
)


_MSG_OPTIONALSERIAL = _descriptor.Descriptor(
    name="MSG_OptionalSerial",
    full_name="org.factcast.grpc.api.gen.MSG_OptionalSerial",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="present",
            full_name="org.factcast.grpc.api.gen.MSG_OptionalSerial.present",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="serial",
            full_name="org.factcast.grpc.api.gen.MSG_OptionalSerial.serial",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=212,
    serialized_end=265,
)


_MSG_NOTIFICATION = _descriptor.Descriptor(
    name="MSG_Notification",
    full_name="org.factcast.grpc.api.gen.MSG_Notification",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="org.factcast.grpc.api.gen.MSG_Notification.type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fact",
            full_name="org.factcast.grpc.api.gen.MSG_Notification.fact",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="id",
            full_name="org.factcast.grpc.api.gen.MSG_Notification.id",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="facts",
            full_name="org.factcast.grpc.api.gen.MSG_Notification.facts",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _MSG_NOTIFICATION_TYPE,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=268,
    serialized_end=567,
)


_MSG_SUBSCRIPTIONREQUEST = _descriptor.Descriptor(
    name="MSG_SubscriptionRequest",
    full_name="org.factcast.grpc.api.gen.MSG_SubscriptionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="json",
            full_name="org.factcast.grpc.api.gen.MSG_SubscriptionRequest.json",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=569,
    serialized_end=608,
)


_MSG_FACTSPECSJSON = _descriptor.Descriptor(
    name="MSG_FactSpecsJson",
    full_name="org.factcast.grpc.api.gen.MSG_FactSpecsJson",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="json",
            full_name="org.factcast.grpc.api.gen.MSG_FactSpecsJson.json",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=610,
    serialized_end=643,
)


_MSG_OPTIONALFACT = _descriptor.Descriptor(
    name="MSG_OptionalFact",
    full_name="org.factcast.grpc.api.gen.MSG_OptionalFact",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="present",
            full_name="org.factcast.grpc.api.gen.MSG_OptionalFact.present",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fact",
            full_name="org.factcast.grpc.api.gen.MSG_OptionalFact.fact",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=645,
    serialized_end=731,
)


_MSG_OPTIONALUUID = _descriptor.Descriptor(
    name="MSG_OptionalUuid",
    full_name="org.factcast.grpc.api.gen.MSG_OptionalUuid",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="present",
            full_name="org.factcast.grpc.api.gen.MSG_OptionalUuid.present",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="uuid",
            full_name="org.factcast.grpc.api.gen.MSG_OptionalUuid.uuid",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=733,
    serialized_end=819,
)


_MSG_FACT = _descriptor.Descriptor(
    name="MSG_Fact",
    full_name="org.factcast.grpc.api.gen.MSG_Fact",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="header",
            full_name="org.factcast.grpc.api.gen.MSG_Fact.header",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="payload",
            full_name="org.factcast.grpc.api.gen.MSG_Fact.payload",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=821,
    serialized_end=864,
)


_MSG_FACTS = _descriptor.Descriptor(
    name="MSG_Facts",
    full_name="org.factcast.grpc.api.gen.MSG_Facts",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="fact",
            full_name="org.factcast.grpc.api.gen.MSG_Facts.fact",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=866,
    serialized_end=928,
)


_MSG_CONDITIONALPUBLISHREQUEST = _descriptor.Descriptor(
    name="MSG_ConditionalPublishRequest",
    full_name="org.factcast.grpc.api.gen.MSG_ConditionalPublishRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="facts",
            full_name="org.factcast.grpc.api.gen.MSG_ConditionalPublishRequest.facts",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="tokenPresent",
            full_name="org.factcast.grpc.api.gen.MSG_ConditionalPublishRequest.tokenPresent",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="token",
            full_name="org.factcast.grpc.api.gen.MSG_ConditionalPublishRequest.token",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=931,
    serialized_end=1089,
)


_MSG_CONDITIONALPUBLISHRESULT = _descriptor.Descriptor(
    name="MSG_ConditionalPublishResult",
    full_name="org.factcast.grpc.api.gen.MSG_ConditionalPublishResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="success",
            full_name="org.factcast.grpc.api.gen.MSG_ConditionalPublishResult.success",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1091,
    serialized_end=1138,
)


_MSG_EMPTY = _descriptor.Descriptor(
    name="MSG_Empty",
    full_name="org.factcast.grpc.api.gen.MSG_Empty",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1140,
    serialized_end=1151,
)


_MSG_SERVERPROTOCOLVERSION = _descriptor.Descriptor(
    name="MSG_ServerProtocolVersion",
    full_name="org.factcast.grpc.api.gen.MSG_ServerProtocolVersion",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="major",
            full_name="org.factcast.grpc.api.gen.MSG_ServerProtocolVersion.major",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="minor",
            full_name="org.factcast.grpc.api.gen.MSG_ServerProtocolVersion.minor",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="patch",
            full_name="org.factcast.grpc.api.gen.MSG_ServerProtocolVersion.patch",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1153,
    serialized_end=1225,
)


_MSG_SERVERPROPERTIES_PROPERTYENTRY = _descriptor.Descriptor(
    name="PropertyEntry",
    full_name="org.factcast.grpc.api.gen.MSG_ServerProperties.PropertyEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="org.factcast.grpc.api.gen.MSG_ServerProperties.PropertyEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="org.factcast.grpc.api.gen.MSG_ServerProperties.PropertyEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1333,
    serialized_end=1380,
)

_MSG_SERVERPROPERTIES = _descriptor.Descriptor(
    name="MSG_ServerProperties",
    full_name="org.factcast.grpc.api.gen.MSG_ServerProperties",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="property",
            full_name="org.factcast.grpc.api.gen.MSG_ServerProperties.property",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _MSG_SERVERPROPERTIES_PROPERTYENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1228,
    serialized_end=1380,
)


_MSG_SERVERCONFIG = _descriptor.Descriptor(
    name="MSG_ServerConfig",
    full_name="org.factcast.grpc.api.gen.MSG_ServerConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="version",
            full_name="org.factcast.grpc.api.gen.MSG_ServerConfig.version",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="properties",
            full_name="org.factcast.grpc.api.gen.MSG_ServerConfig.properties",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1383,
    serialized_end=1541,
)


_MSG_STRINGSET = _descriptor.Descriptor(
    name="MSG_StringSet",
    full_name="org.factcast.grpc.api.gen.MSG_StringSet",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="embeddedString",
            full_name="org.factcast.grpc.api.gen.MSG_StringSet.embeddedString",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1543,
    serialized_end=1582,
)


_MSG_STRING = _descriptor.Descriptor(
    name="MSG_String",
    full_name="org.factcast.grpc.api.gen.MSG_String",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="embeddedString",
            full_name="org.factcast.grpc.api.gen.MSG_String.embeddedString",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1584,
    serialized_end=1620,
)


_MSG_STATEFORREQUEST = _descriptor.Descriptor(
    name="MSG_StateForRequest",
    full_name="org.factcast.grpc.api.gen.MSG_StateForRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="nsPresent",
            full_name="org.factcast.grpc.api.gen.MSG_StateForRequest.nsPresent",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ns",
            full_name="org.factcast.grpc.api.gen.MSG_StateForRequest.ns",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="aggIds",
            full_name="org.factcast.grpc.api.gen.MSG_StateForRequest.aggIds",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1622,
    serialized_end=1727,
)


_MSG_CURRENTDATABASETIME = _descriptor.Descriptor(
    name="MSG_CurrentDatabaseTime",
    full_name="org.factcast.grpc.api.gen.MSG_CurrentDatabaseTime",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="millis",
            full_name="org.factcast.grpc.api.gen.MSG_CurrentDatabaseTime.millis",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1729,
    serialized_end=1770,
)


_MSG_SNAPSHOTID = _descriptor.Descriptor(
    name="MSG_SnapshotId",
    full_name="org.factcast.grpc.api.gen.MSG_SnapshotId",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="org.factcast.grpc.api.gen.MSG_SnapshotId.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="uuid",
            full_name="org.factcast.grpc.api.gen.MSG_SnapshotId.uuid",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1772,
    serialized_end=1860,
)


_MSG_SNAPSHOT = _descriptor.Descriptor(
    name="MSG_Snapshot",
    full_name="org.factcast.grpc.api.gen.MSG_Snapshot",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="org.factcast.grpc.api.gen.MSG_Snapshot.id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="factId",
            full_name="org.factcast.grpc.api.gen.MSG_Snapshot.factId",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="org.factcast.grpc.api.gen.MSG_Snapshot.data",
            index=2,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="compressed",
            full_name="org.factcast.grpc.api.gen.MSG_Snapshot.compressed",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1863,
    serialized_end=2019,
)


_MSG_OPTIONALSNAPSHOT = _descriptor.Descriptor(
    name="MSG_OptionalSnapshot",
    full_name="org.factcast.grpc.api.gen.MSG_OptionalSnapshot",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="present",
            full_name="org.factcast.grpc.api.gen.MSG_OptionalSnapshot.present",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="snapshot",
            full_name="org.factcast.grpc.api.gen.MSG_OptionalSnapshot.snapshot",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2021,
    serialized_end=2119,
)

_MSG_UUIDS.fields_by_name["uuids"].message_type = _MSG_UUID
_MSG_NOTIFICATION.fields_by_name["type"].enum_type = _MSG_NOTIFICATION_TYPE
_MSG_NOTIFICATION.fields_by_name["fact"].message_type = _MSG_FACT
_MSG_NOTIFICATION.fields_by_name["id"].message_type = _MSG_UUID
_MSG_NOTIFICATION.fields_by_name["facts"].message_type = _MSG_FACTS
_MSG_NOTIFICATION_TYPE.containing_type = _MSG_NOTIFICATION
_MSG_OPTIONALFACT.fields_by_name["fact"].message_type = _MSG_FACT
_MSG_OPTIONALUUID.fields_by_name["uuid"].message_type = _MSG_UUID
_MSG_FACTS.fields_by_name["fact"].message_type = _MSG_FACT
_MSG_CONDITIONALPUBLISHREQUEST.fields_by_name["facts"].message_type = _MSG_FACTS
_MSG_CONDITIONALPUBLISHREQUEST.fields_by_name["token"].message_type = _MSG_UUID
_MSG_SERVERPROPERTIES_PROPERTYENTRY.containing_type = _MSG_SERVERPROPERTIES
_MSG_SERVERPROPERTIES.fields_by_name[
    "property"
].message_type = _MSG_SERVERPROPERTIES_PROPERTYENTRY
_MSG_SERVERCONFIG.fields_by_name["version"].message_type = _MSG_SERVERPROTOCOLVERSION
_MSG_SERVERCONFIG.fields_by_name["properties"].message_type = _MSG_SERVERPROPERTIES
_MSG_STATEFORREQUEST.fields_by_name["aggIds"].message_type = _MSG_UUID
_MSG_SNAPSHOTID.fields_by_name["uuid"].message_type = _MSG_OPTIONALUUID
_MSG_SNAPSHOT.fields_by_name["id"].message_type = _MSG_SNAPSHOTID
_MSG_SNAPSHOT.fields_by_name["factId"].message_type = _MSG_UUID
_MSG_OPTIONALSNAPSHOT.fields_by_name["snapshot"].message_type = _MSG_SNAPSHOT
DESCRIPTOR.message_types_by_name["MSG_UUID"] = _MSG_UUID
DESCRIPTOR.message_types_by_name["MSG_UUID_AND_VERSION"] = _MSG_UUID_AND_VERSION
DESCRIPTOR.message_types_by_name["MSG_UUIDs"] = _MSG_UUIDS
DESCRIPTOR.message_types_by_name["MSG_OptionalSerial"] = _MSG_OPTIONALSERIAL
DESCRIPTOR.message_types_by_name["MSG_Notification"] = _MSG_NOTIFICATION
DESCRIPTOR.message_types_by_name["MSG_SubscriptionRequest"] = _MSG_SUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name["MSG_FactSpecsJson"] = _MSG_FACTSPECSJSON
DESCRIPTOR.message_types_by_name["MSG_OptionalFact"] = _MSG_OPTIONALFACT
DESCRIPTOR.message_types_by_name["MSG_OptionalUuid"] = _MSG_OPTIONALUUID
DESCRIPTOR.message_types_by_name["MSG_Fact"] = _MSG_FACT
DESCRIPTOR.message_types_by_name["MSG_Facts"] = _MSG_FACTS
DESCRIPTOR.message_types_by_name[
    "MSG_ConditionalPublishRequest"
] = _MSG_CONDITIONALPUBLISHREQUEST
DESCRIPTOR.message_types_by_name[
    "MSG_ConditionalPublishResult"
] = _MSG_CONDITIONALPUBLISHRESULT
DESCRIPTOR.message_types_by_name["MSG_Empty"] = _MSG_EMPTY
DESCRIPTOR.message_types_by_name[
    "MSG_ServerProtocolVersion"
] = _MSG_SERVERPROTOCOLVERSION
DESCRIPTOR.message_types_by_name["MSG_ServerProperties"] = _MSG_SERVERPROPERTIES
DESCRIPTOR.message_types_by_name["MSG_ServerConfig"] = _MSG_SERVERCONFIG
DESCRIPTOR.message_types_by_name["MSG_StringSet"] = _MSG_STRINGSET
DESCRIPTOR.message_types_by_name["MSG_String"] = _MSG_STRING
DESCRIPTOR.message_types_by_name["MSG_StateForRequest"] = _MSG_STATEFORREQUEST
DESCRIPTOR.message_types_by_name["MSG_CurrentDatabaseTime"] = _MSG_CURRENTDATABASETIME
DESCRIPTOR.message_types_by_name["MSG_SnapshotId"] = _MSG_SNAPSHOTID
DESCRIPTOR.message_types_by_name["MSG_Snapshot"] = _MSG_SNAPSHOT
DESCRIPTOR.message_types_by_name["MSG_OptionalSnapshot"] = _MSG_OPTIONALSNAPSHOT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MSG_UUID = _reflection.GeneratedProtocolMessageType(
    "MSG_UUID",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_UUID,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_UUID)
    },
)
_sym_db.RegisterMessage(MSG_UUID)

MSG_UUID_AND_VERSION = _reflection.GeneratedProtocolMessageType(
    "MSG_UUID_AND_VERSION",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_UUID_AND_VERSION,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_UUID_AND_VERSION)
    },
)
_sym_db.RegisterMessage(MSG_UUID_AND_VERSION)

MSG_UUIDs = _reflection.GeneratedProtocolMessageType(
    "MSG_UUIDs",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_UUIDS,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_UUIDs)
    },
)
_sym_db.RegisterMessage(MSG_UUIDs)

MSG_OptionalSerial = _reflection.GeneratedProtocolMessageType(
    "MSG_OptionalSerial",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_OPTIONALSERIAL,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_OptionalSerial)
    },
)
_sym_db.RegisterMessage(MSG_OptionalSerial)

MSG_Notification = _reflection.GeneratedProtocolMessageType(
    "MSG_Notification",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_NOTIFICATION,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_Notification)
    },
)
_sym_db.RegisterMessage(MSG_Notification)

MSG_SubscriptionRequest = _reflection.GeneratedProtocolMessageType(
    "MSG_SubscriptionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_SUBSCRIPTIONREQUEST,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_SubscriptionRequest)
    },
)
_sym_db.RegisterMessage(MSG_SubscriptionRequest)

MSG_FactSpecsJson = _reflection.GeneratedProtocolMessageType(
    "MSG_FactSpecsJson",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_FACTSPECSJSON,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_FactSpecsJson)
    },
)
_sym_db.RegisterMessage(MSG_FactSpecsJson)

MSG_OptionalFact = _reflection.GeneratedProtocolMessageType(
    "MSG_OptionalFact",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_OPTIONALFACT,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_OptionalFact)
    },
)
_sym_db.RegisterMessage(MSG_OptionalFact)

MSG_OptionalUuid = _reflection.GeneratedProtocolMessageType(
    "MSG_OptionalUuid",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_OPTIONALUUID,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_OptionalUuid)
    },
)
_sym_db.RegisterMessage(MSG_OptionalUuid)

MSG_Fact = _reflection.GeneratedProtocolMessageType(
    "MSG_Fact",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_FACT,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_Fact)
    },
)
_sym_db.RegisterMessage(MSG_Fact)

MSG_Facts = _reflection.GeneratedProtocolMessageType(
    "MSG_Facts",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_FACTS,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_Facts)
    },
)
_sym_db.RegisterMessage(MSG_Facts)

MSG_ConditionalPublishRequest = _reflection.GeneratedProtocolMessageType(
    "MSG_ConditionalPublishRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_CONDITIONALPUBLISHREQUEST,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_ConditionalPublishRequest)
    },
)
_sym_db.RegisterMessage(MSG_ConditionalPublishRequest)

MSG_ConditionalPublishResult = _reflection.GeneratedProtocolMessageType(
    "MSG_ConditionalPublishResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_CONDITIONALPUBLISHRESULT,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_ConditionalPublishResult)
    },
)
_sym_db.RegisterMessage(MSG_ConditionalPublishResult)

MSG_Empty = _reflection.GeneratedProtocolMessageType(
    "MSG_Empty",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_EMPTY,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_Empty)
    },
)
_sym_db.RegisterMessage(MSG_Empty)

MSG_ServerProtocolVersion = _reflection.GeneratedProtocolMessageType(
    "MSG_ServerProtocolVersion",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_SERVERPROTOCOLVERSION,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_ServerProtocolVersion)
    },
)
_sym_db.RegisterMessage(MSG_ServerProtocolVersion)

MSG_ServerProperties = _reflection.GeneratedProtocolMessageType(
    "MSG_ServerProperties",
    (_message.Message,),
    {
        "PropertyEntry": _reflection.GeneratedProtocolMessageType(
            "PropertyEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _MSG_SERVERPROPERTIES_PROPERTYENTRY,
                "__module__": "FactStore_pb2"
                # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_ServerProperties.PropertyEntry)
            },
        ),
        "DESCRIPTOR": _MSG_SERVERPROPERTIES,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_ServerProperties)
    },
)
_sym_db.RegisterMessage(MSG_ServerProperties)
_sym_db.RegisterMessage(MSG_ServerProperties.PropertyEntry)

MSG_ServerConfig = _reflection.GeneratedProtocolMessageType(
    "MSG_ServerConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_SERVERCONFIG,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_ServerConfig)
    },
)
_sym_db.RegisterMessage(MSG_ServerConfig)

MSG_StringSet = _reflection.GeneratedProtocolMessageType(
    "MSG_StringSet",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_STRINGSET,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_StringSet)
    },
)
_sym_db.RegisterMessage(MSG_StringSet)

MSG_String = _reflection.GeneratedProtocolMessageType(
    "MSG_String",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_STRING,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_String)
    },
)
_sym_db.RegisterMessage(MSG_String)

MSG_StateForRequest = _reflection.GeneratedProtocolMessageType(
    "MSG_StateForRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_STATEFORREQUEST,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_StateForRequest)
    },
)
_sym_db.RegisterMessage(MSG_StateForRequest)

MSG_CurrentDatabaseTime = _reflection.GeneratedProtocolMessageType(
    "MSG_CurrentDatabaseTime",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_CURRENTDATABASETIME,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_CurrentDatabaseTime)
    },
)
_sym_db.RegisterMessage(MSG_CurrentDatabaseTime)

MSG_SnapshotId = _reflection.GeneratedProtocolMessageType(
    "MSG_SnapshotId",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_SNAPSHOTID,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_SnapshotId)
    },
)
_sym_db.RegisterMessage(MSG_SnapshotId)

MSG_Snapshot = _reflection.GeneratedProtocolMessageType(
    "MSG_Snapshot",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_SNAPSHOT,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_Snapshot)
    },
)
_sym_db.RegisterMessage(MSG_Snapshot)

MSG_OptionalSnapshot = _reflection.GeneratedProtocolMessageType(
    "MSG_OptionalSnapshot",
    (_message.Message,),
    {
        "DESCRIPTOR": _MSG_OPTIONALSNAPSHOT,
        "__module__": "FactStore_pb2"
        # @@protoc_insertion_point(class_scope:org.factcast.grpc.api.gen.MSG_OptionalSnapshot)
    },
)
_sym_db.RegisterMessage(MSG_OptionalSnapshot)


DESCRIPTOR._options = None
_MSG_SERVERPROPERTIES_PROPERTYENTRY._options = None

_REMOTEFACTSTORE = _descriptor.ServiceDescriptor(
    name="RemoteFactStore",
    full_name="org.factcast.grpc.api.gen.RemoteFactStore",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=2122,
    serialized_end=3808,
    methods=[
        _descriptor.MethodDescriptor(
            name="subscribe",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.subscribe",
            index=0,
            containing_service=None,
            input_type=_MSG_SUBSCRIPTIONREQUEST,
            output_type=_MSG_NOTIFICATION,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="fetchById",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.fetchById",
            index=1,
            containing_service=None,
            input_type=_MSG_UUID,
            output_type=_MSG_OPTIONALFACT,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="publish",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.publish",
            index=2,
            containing_service=None,
            input_type=_MSG_FACTS,
            output_type=_MSG_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="serialOf",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.serialOf",
            index=3,
            containing_service=None,
            input_type=_MSG_UUID,
            output_type=_MSG_OPTIONALSERIAL,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="handshake",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.handshake",
            index=4,
            containing_service=None,
            input_type=_MSG_EMPTY,
            output_type=_MSG_SERVERCONFIG,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="enumerateNamespaces",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.enumerateNamespaces",
            index=5,
            containing_service=None,
            input_type=_MSG_EMPTY,
            output_type=_MSG_STRINGSET,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="enumerateTypes",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.enumerateTypes",
            index=6,
            containing_service=None,
            input_type=_MSG_STRING,
            output_type=_MSG_STRINGSET,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="publishConditional",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.publishConditional",
            index=7,
            containing_service=None,
            input_type=_MSG_CONDITIONALPUBLISHREQUEST,
            output_type=_MSG_CONDITIONALPUBLISHRESULT,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="invalidate",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.invalidate",
            index=8,
            containing_service=None,
            input_type=_MSG_UUID,
            output_type=_MSG_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="stateFor",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.stateFor",
            index=9,
            containing_service=None,
            input_type=_MSG_STATEFORREQUEST,
            output_type=_MSG_UUID,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="currentTime",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.currentTime",
            index=10,
            containing_service=None,
            input_type=_MSG_EMPTY,
            output_type=_MSG_CURRENTDATABASETIME,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="fetchByIdAndVersion",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.fetchByIdAndVersion",
            index=11,
            containing_service=None,
            input_type=_MSG_UUID_AND_VERSION,
            output_type=_MSG_OPTIONALFACT,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="clearSnapshot",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.clearSnapshot",
            index=12,
            containing_service=None,
            input_type=_MSG_SNAPSHOTID,
            output_type=_MSG_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="setSnapshot",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.setSnapshot",
            index=13,
            containing_service=None,
            input_type=_MSG_SNAPSHOT,
            output_type=_MSG_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="getSnapshot",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.getSnapshot",
            index=14,
            containing_service=None,
            input_type=_MSG_SNAPSHOTID,
            output_type=_MSG_OPTIONALSNAPSHOT,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="stateForSpecsJson",
            full_name="org.factcast.grpc.api.gen.RemoteFactStore.stateForSpecsJson",
            index=15,
            containing_service=None,
            input_type=_MSG_FACTSPECSJSON,
            output_type=_MSG_UUID,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_REMOTEFACTSTORE)

DESCRIPTOR.services_by_name["RemoteFactStore"] = _REMOTEFACTSTORE

# @@protoc_insertion_point(module_scope)



from __future__ import annotations

from typing import Type, TypeVar, Dict, List, Optional

from pyfactcast.grpc.generated.FactStore_pb2 import MSG_Notification
from pydantic import BaseModel, Extra, constr

import json

F = TypeVar("F", bound="Fact")


class CatchUp:
    pass


# Sadly pydantic and mypy do not play nice here.
Id: constr = constr(  # type: ignore
    regex=r"^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
)
AggsId: constr = constr(  # type: ignore
    regex=r"^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
)


class FactHeader(BaseModel):
    class Config:
        extra = Extra.allow

    ns: str
    type: str
    id: Id  # type: ignore
    aggIds: Optional[List[AggsId]] = None  # type: ignore
    meta: Dict[str, str] = {}


class Fact(BaseModel):
    header: FactHeader
    payload: Dict

    @classmethod
    def from_msg(cls: Type[F], msg: MSG_Notification) -> F:
        return cls(
            header=json.loads(msg.fact.header), payload=json.loads(msg.fact.payload)
        )
